<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="es">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de aplicación</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Una vez configurado, active la opción &quot;Usar un proxy&quot; haciendo clic derecho sobre las aplicaciones en el lanzador.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Puerto inválido</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>¿Está seguro que desea borrar la configuración?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexión cableada %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Conexión inalámbrica %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexión PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nueva VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo de VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de aplicación</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Compartir conexión personal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalles de red</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Tarjeta de red cableada</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Añadir conexión de red</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Tarjeta de red inalámbrica</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar a red oculta</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crear conexión PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Estado de la VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crear VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configurar URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Compartir conexión</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Crear conexión compartida</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Habilitar el modo avión apagara la red inalámbrica, el punto de acceso personal y Bluetooth</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Dirección DNS inválida</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Sin enlazar</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Dirección MAC del dispositivo</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Dirección MAC clonada</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar el MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>El nombre ya existe</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Conectar automáticamente</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Añadir ajustes</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Crear conexión compartida</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Dirección IP duplicada</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de red inválida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Sólo se permite un gateway</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace inválida</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Dirección IP duplicada</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Sólo se permite un gateway</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace inválida</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Solo aplicable a los recursos correspondientes</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de red inválida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace inválida</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detalles de red</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy de aplicación</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo avión</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalles de red</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configurar con administrador de red</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Compartir conexión personal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servicio</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Negar autenticación EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Negar autenticación PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Negar autenticación CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Negar autenticación MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Negar autenticación MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sin compresión de datos BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sin compresión de datos por deflación</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sin compresión en cabecera TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sin compresión en el campo de protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sin compresión de dirección y control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar paquetes eco PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Estado de MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crear conexión PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorar las configuraciones de proxy para los hosts y dominios anteriores</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configurar URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS tunelizado</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegido</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Guardar la contraseña para este usuario</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Guardar la contraseña para todos los usuarios</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pregúntarme siempre</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anónimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático </translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versión 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versión 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticación EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidad</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opciones de Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clave privada</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anónimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisionamiento</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Archivo PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticación interna</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versión PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Contraseña inválida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Seguridad requerida</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Contraseña inválida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clave compartida</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistema abierto</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticación</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzado</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalizar puerto de la puerta de enlace</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalizar intervalo de renegociación</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalo de renegociación</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Utilizar compresión LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usar conexión TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usar dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalizar túnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalizar tamaño del fragmento UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Tamaño del fragmento UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringir el túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Aleatorizar hosts remotos</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzado</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (por defecto)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Seguro (por defecto)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Débil</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T si está disponible (por defecto)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T siempre</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupo 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupo 2 (por defecto)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupo 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (por defecto)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupo 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Dominio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Proveedor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Modo de recorrido NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupo IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Reenvío secreto</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Puerto local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Desactivar detección de pares muertos</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Habilitar IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nombre del grupo</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID de grupo</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clave precompartida</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmos de Fase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmos de Fase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace no válida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permitir el troyano Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clave privada</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Usar FSID para la frase de contraseña</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace no válida</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificados (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificados con contraseña (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Clave estática</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticación</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clave privada</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opc. contras.</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar key direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key direction</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP remota</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Todos disponibles (por defecto)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (menos seguro)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (más seguro)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Negar autenticación EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Negar autenticación PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Negar autenticación CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Negar autenticación MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Negar autenticación MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sin compresión de datos BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sin compresión de datos por deflación</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sin compresión en cabecera TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sin compresión en el campo de protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sin compresión de dirección y control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar paquetes eco PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Estado de MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Estado de la VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crear VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Error al importar</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Error en el archivo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No requerido</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Servidor IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Si falla reintentar indefinidamente </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Archivo CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorar advertencias de certificado</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Usar extensiones para hostname TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Seguridad VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Por defecto</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticación HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace no válida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opc. contras.</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Dominio NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Servidor IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace no válida</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clave privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Tarjeta inteligente</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clave precompartida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticación</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitar una dirección IP interna</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Forzar encapsulación UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usar compresión IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation> Habilitar propuestas de cifrado personalizadas </translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticación TLS VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Por defecto</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Coincidir nombres</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo de certificado remoto</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Archivo de clave</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar key direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key direction</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace no válida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opc. contras.</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nombre del grupo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Contraseña de grupo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Usar autenticación híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Archivo CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Conecte en el cable de red primero</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Tarjeta de red cableada</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Añadir conexión de red</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Seleccionar ajustes</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Tarjeta de red inalámbrica</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation> Cerrar conexión compartida </translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Desactive la conexión compartida si desea conectarse a una red inalámbrica</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectar a red oculta</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Sin enlazar</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Dirección MAC del dispositivo</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar el MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>